@@ -1,7 +1,7 @@
 SSplotComps <-
-  function(replist, subplots=1:9,
-           kind="LEN", aalyear=-1, aalbin=-1, plot=TRUE, print=FALSE, fleets="all",
-           fleetnames="default",
+  function(replist, subplots=1:11,
+           kind="LEN", sizemethod=1, aalyear=-1, aalbin=-1, plot=TRUE, print=FALSE,
+           fleets="all", fleetnames="default",
            datonly=FALSE, samplesizeplots=TRUE, compresidplots=TRUE, bub=FALSE,
            showsampsize=TRUE, showeffN=TRUE, minnbubble=8, pntscalar=2.6,
            pwidth=7, pheight=7, punits="in", ptsize=12, res=300,
@@ -15,19 +15,21 @@ SSplotComps <-
                       "Proportion",            #6
                       "cm",                    #7
                       "Frequency",             #8
-                      "Weight (lbs)",          #9
-                      "(mt)",                  #10
-                      "(numbers x1000)",       #11
-                      "Stdev (Age) (yr)",      #12
-                      "Andre's conditional AAL plot, "), #13
+                      "Weight",                #9
+                      "Length",                #10
+                      "(mt)",                  #11
+                      "(numbers x1000)",       #12
+                      "Stdev (Age) (yr)",      #13
+                      "Andre's conditional AAL plot, "), #14
            printmkt=TRUE,printsex=TRUE,
            maxrows=6,maxcols=6,maxrows2=2,maxcols2=4,rows=1,cols=1,
-           fixdims=TRUE,maxneff=5000,verbose=TRUE,...)
+           fixdims=TRUE,fixdims2=FALSE,maxneff=5000,verbose=TRUE,
+           scalebins=FALSE,...)
 {
   ################################################################################
-  # SSplotComps October 21, 2010
+  # SSplotComps March 23, 2011
   ################################################################################
-
+  if(!exists("make_multifig")) stop("you are missing the function 'make_mulitifig'")
   pngfun <- function(file) png(file=file,width=pwidth,height=pheight,units=punits,res=res,pointsize=ptsize)
 
   lendbase      <- replist$lendbase
@@ -43,11 +45,10 @@ SSplotComps <-
 
   nfleets       <- replist$nfleets
   nseasons      <- replist$nseasons
+  seasfracs     <- replist$seasfracs
   FleetNames    <- replist$FleetNames
   nsexes        <- replist$nsexes
 
-  if(!exists("make_multifig")) stop("you are missing the function 'make_mulitifig'")
-
   titles <- NULL
   if(plotdir=="default") plotdir <- replist$inputs$dir
 
@@ -84,8 +85,15 @@ SSplotComps <-
     }
   }
   if(kind=="SIZE"){
-    dbase_kind <- sizedbase
-    kindlab=labels[9]
+    dbase_kind <- sizedbase[sizedbase$method==sizemethod,]
+    sizeunits <- unique(dbase_kind$units)
+    if(length(sizeunits)>1)
+      stop("!error with size units in generalized size comp plots:\n",
+           "    more than one unit value per method.\n")
+    if(sizeunits %in% c("in","cm"))
+      kindlab <- paste(labels[10]," (",sizeunits,")",sep="")
+    if(sizeunits %in% c("lb","kg"))
+        kindlab <- paste(labels[9]," (",sizeunits,")",sep="")
     if(datonly){
       filenamestart <- "comp_sizedat_"
       titledata <- "size comp data, "
@@ -207,7 +215,7 @@ SSplotComps <-
 
           # aggregating identifiers for plot titles and filenames
           title_sexmkt <- paste(titlesex,titlemkt,sep="")
-          filename_fltsexmkt <- paste("flt",f,"sex",sex,"mkt",j,sep="")
+          filename_fltsexmkt <- paste("flt",f,"sex",k,"mkt",j,sep="")
 
           ### subplot 1: multi-panel composition plot
           if(1 %in% subplots & kind!="cond") # for age or length comps, but not conditional AAL
@@ -215,6 +223,7 @@ SSplotComps <-
             ptitle <- paste(titledata,title_sexmkt, fleetnames[f],sep="") # total title
             titles <- c(ptitle,titles) # compiling list of all plot titles
             tempfun <- function(ipage,...){
+              # a function to combine a bunch of repeated commands
               if(!(kind %in% c("GSTAGE","GSTLEN","L@A","W@A"))){
                 make_multifig(ptsx=dbase$Bin,ptsy=dbase$Obs,yr=dbase$Yr,linesx=dbase$Bin,linesy=dbase$Exp,
                               sampsize=dbase$N,effN=dbase$effN,showsampsize=showsampsize,showeffN=showeffN,
@@ -222,7 +231,7 @@ SSplotComps <-
                               nlegends=3,legtext=list(dbase$YrSeasName,"sampsize","effN"),
                               main=ptitle,cex.main=cex.main,xlab=kindlab,ylab=labels[6],
                               maxrows=maxrows,maxcols=maxcols,rows=rows,cols=cols,
-                              fixdims=fixdims,ipage=ipage,...)
+                              fixdims=fixdims,ipage=ipage,scalebins=scalebins,...)
               }
               if(kind=="GSTAGE"){
                   make_multifig(ptsx=dbase$Bin,ptsy=dbase$Obs,yr=dbase$Yr,linesx=dbase$Bin,linesy=dbase$Exp,
@@ -231,7 +240,7 @@ SSplotComps <-
                                 nlegends=3,legtext=list(dbase$YrSeasName,"sampsize","effN"),
                                 main=ptitle,cex.main=cex.main,xlab=kindlab,ylab=labels[6],
                                 maxrows=maxrows,maxcols=maxcols,rows=rows,cols=cols,
-                                fixdims=fixdims,ipage=ipage,...)
+                                fixdims=fixdims,ipage=ipage,scalebins=scalebins,...)
               }
               if(kind=="GSTLEN"){
                   make_multifig(ptsx=dbase$Bin,ptsy=dbase$Obs,yr=dbase$Yr,linesx=dbase$Bin,linesy=dbase$Exp,
@@ -240,7 +249,7 @@ SSplotComps <-
                                 nlegends=3,legtext=list(dbase$YrSeasName,"sampsize","effN"),
                                 main=ptitle,cex.main=cex.main,xlab=kindlab,ylab=labels[6],
                                 maxrows=maxrows,maxcols=maxcols,rows=rows,cols=cols,
-                                fixdims=fixdims,ipage=ipage,...)
+                                fixdims=fixdims,ipage=ipage,scalebins=scalebins,...)
               }
               if(kind %in% c("L@A","W@A")){
                   make_multifig(ptsx=dbase$Bin,ptsy=dbase$Obs,yr=dbase$Yr,linesx=dbase$Bin,linesy=dbase$Exp,
@@ -250,10 +259,10 @@ SSplotComps <-
                                 bars=bars,linepos=(1-datonly)*linepos,
                                 main=ptitle,cex.main=cex.main,xlab=kindlab,ylab=ifelse(kind=="W@A",labels[9],labels[1]),
                                 maxrows=maxrows,maxcols=maxcols,rows=rows,cols=cols,
-                                fixdims=fixdims,ipage=ipage,...)
+                                fixdims=fixdims,ipage=ipage,scalebins=scalebins,...)
               }
-
-            }
+            } # end tempfun
+            
             if(plot) tempfun(ipage=0,...)
             if(print){ # set up plotting to png file if required
               npages <- ceiling(length(unique(dbase$Yr))/maxrows/maxcols)
@@ -333,7 +342,7 @@ SSplotComps <-
                         bars=FALSE,linepos=0,main=ptitle,cex.main=cex.main,
                         xlab=labels[2],ylab=labels[1],ymin0=FALSE,maxrows=maxrows2,maxcols=maxcols2,
                         fixdims=fixdims,allopen=allopen,minnbubble=minnbubble,
-                        ptscol=col[1],ptscol2=col[2],ipage=ipage,...)
+                        ptscol=col[1],ptscol2=col[2],ipage=ipage,scalebins=scalebins,...)
             }
             if(plot) tempfun(ipage=0,...)
             if(print){ # set up plotting to png file if required
@@ -371,8 +380,7 @@ SSplotComps <-
                                   nlegends=3,legtext=list(lenbinlegend,"sampsize","effN"),
                                   bars=FALSE,linepos=linepos,main=ptitle,cex.main=cex.main,
                                   xlab=labels[2],ylab=labels[6],maxrows=maxrows,maxcols=maxcols,rows=rows,cols=cols,
-
-                                  fixdims=fixdims,ipage=ipage,...)
+                                  fixdims=fixdims,ipage=ipage,scalebins=scalebins,...)
                   }
                   if(plot) tempfun(ipage=0,...)
                   if(print){
@@ -436,7 +444,7 @@ SSplotComps <-
                               nlegends=3,legtext=list(abindbase$YrSeasName,"sampsize","effN"),
                               bars=bars,linepos=(1-datonly)*linepos,
                               main=ptitle,cex.main=cex.main,xlab=kindlab,ylab=labels[6],maxrows=maxrows,maxcols=maxcols,rows=rows,cols=cols,
-                              fixdims=fixdims,ipage=ipage,...)
+                              fixdims=fixdims,ipage=ipage,scalebins=scalebins,...)
                 }
                 if(plot) tempfun(ipage=0,...)
                 if(print){
@@ -523,7 +531,7 @@ SSplotComps <-
                     Pred <- c(Pred,PredV)
                     varn <-sqrt(PredV2-PredV*PredV)/sqrt(NN)
                     Pred2 <- c(Pred2,varn)
-                    varn <-sqrt(ObsV2-ObsV*ObsV)/sqrt(NN)
+                    varn <-sqrt(max(0,ObsV2-ObsV*ObsV))/sqrt(NN)
                     Obs2 <- c(Obs2,varn)
                     Low <- c(Low,ObsV-1.64*varn)
                     Upp <- c(Upp,ObsV+1.64*varn)
@@ -544,13 +552,13 @@ SSplotComps <-
                 lines(Size,Upp,lty=3)
                 #title(paste("Year = ",Yr,"; Gender = ",Gender))
 
-                ptitle <- paste(labels[13], title_sexmkt, fleetnames[f],sep="")
+                ptitle <- paste(labels[14], title_sexmkt, fleetnames[f],sep="")
                 titles <- c(ptitle,titles) # compiling list of all plot titles
                 if(par("mfg")[1] & par("mfg")[2]==1){ # first plot on any new page
                   title(main=ptitle,xlab=labels[1],outer=TRUE,line=1)
                 }
                 ymax <- max(Obs2,Pred2)*1.1
-                plot(Size,Obs2,xlab=labels[1],ylab=labels[12],pch=16,xlim=c(min(Lens),max(Lens)),ylim=c(0,ymax),yaxs="i")
+                plot(Size,Obs2,xlab=labels[1],ylab=labels[13],pch=16,xlim=c(min(Lens),max(Lens)),ylim=c(0,ymax),yaxs="i")
                 lines(Size,Pred2)
                 lines(Size2,Low2,lty=3)
                 lines(Size2,Upp2,lty=3)
@@ -608,33 +616,33 @@ SSplotComps <-
   
             # aggregating identifiers for plot titles and filenames
             title_sexmkt <- paste(titlesex,titlemkt,sep="")
-            filename_fltsexmkt <- paste("flt",f,"sex",sex,"mkt",j,sep="")
+            filename_fltsexmkt <- paste("sex",k,"mkt",j,sep="")
   
             ptitle <- paste(titledata,title_sexmkt, "aggregated across time by fleet",sep="") # total title
             titles <- c(ptitle,titles) # compiling list of all plot titles
   
+            Bins <- sort(unique(dbase$Bin))
+            nbins <- length(Bins)
+            df <- data.frame(N=dbase$N,
+                             effN=dbase$effN,
+                             obs=dbase$Obs*dbase$N,
+                             exp=dbase$Exp*dbase$N)
+            agg <- aggregate(x=df, by=list(bin=dbase$Bin,f=dbase$Fleet), FUN=sum)
+            agg <- agg[agg$f %in% fleets,]
+            agg$obs <- agg$obs/agg$N
+            agg$exp <- agg$exp/agg$N
+            # note: sample sizes will be different for each bin if tail compression is used
+            #       printed sample sizes in plot will be maximum, which may or may not
+            #       represent sum of sample sizes over all years/ages
+            for(f in unique(agg$f)){
+              infleet <- agg$f==f
+              agg$N[infleet] <- max(agg$N[infleet])
+              agg$effN[infleet] <- max(agg$effN[infleet])
+            }
+
+            namesvec <- fleetnames[agg$f]
             # group remaining calculations as a function
             tempfun <- function(ipage,...){
-              Bins <- sort(unique(dbase$Bin))
-              nbins <- length(Bins)
-              df <- data.frame(N=dbase$N,
-                               effN=dbase$effN,
-                               obs=dbase$Obs*dbase$N,
-                               exp=dbase$Exp*dbase$N)
-              agg <- aggregate(x=df, by=list(bin=dbase$Bin,f=dbase$Fleet), FUN=sum)
-              agg <- agg[agg$f %in% fleets,]
-              agg$obs <- agg$obs/agg$N
-              agg$exp <- agg$exp/agg$N
-              # note: sample sizes will be different for each bin if tail compression is used
-              #       printed sample sizes in plot will be maximum, which may or may not
-              #       represent sum of sample sizes over all years/ages
-              for(f in unique(agg$f)){
-                infleet <- agg$f==f
-                agg$N[infleet] <- max(agg$N[infleet])
-                agg$effN[infleet] <- max(agg$effN[infleet])
-              }
-  
-              namesvec <- fleetnames[agg$f]
               if(!(kind %in% c("GSTAGE","GSTLEN","L@A","W@A"))){
                 make_multifig(ptsx=agg$bin,ptsy=agg$obs,yr=agg$f,
                               linesx=agg$bin,linesy=agg$exp,
@@ -645,7 +653,7 @@ SSplotComps <-
                               legtext=list(namesvec,"sampsize","effN"),
                               main=ptitle,cex.main=cex.main,xlab=kindlab,ylab=labels[6],
                               maxrows=maxrows,maxcols=maxcols,rows=rows,cols=cols,
-                              fixdims=F,ipage=ipage,lwd=2,...)
+                              fixdims=fixdims2,ipage=ipage,lwd=2,scalebins=scalebins,...)
               }
   
          # haven't configured this aggregated plot for other types
@@ -671,11 +679,11 @@ SSplotComps <-
             }
             if(plot) tempfun(ipage=0,...) 
             if(print){ # set up plotting to png file if required
-              npages <- ceiling(length(unique(dbase$Yr))/maxrows/maxcols)
+              npages <- ceiling(length(unique(agg$f))/maxrows/maxcols)
               for(ipage in 1:npages)
               {
                 if(npages>1) pagetext <- paste("_page",ipage,sep="") else pagetext <- ""
-                filename <- paste(plotdir,filenamestart,filename_fltsexmkt,pagetext,".png",sep="")
+                filename <- paste(plotdir,filenamestart,filename_fltsexmkt,pagetext,"aggregated across time.png",sep="")
                 pngfun(file=filename)
                 tempfun(ipage=ipage,...)
                 dev.off()
@@ -686,7 +694,260 @@ SSplotComps <-
       } # end loop over combined/not-combined genders
     } # end if data
   } # end subplot 9
+
+  ### subplot 10: by fleet aggregating across years
+  if(10 %in% subplots & kind!="cond" & nseasons>1) # for age or length comps, but not conditional AAL
+  {
+    dbasef <- dbase_kind[dbase_kind$Fleet %in% fleets,]
+    # check for the presence of data
+    if(nrow(dbasef)>0)
+    {
+      testor    <- length(dbasef$Gender[dbasef$Gender==1 & dbasef$Pick_gender==0 ])>0
+      testor[2] <- length(dbasef$Gender[dbasef$Gender==1 & dbasef$Pick_gender %in% c(1,3)])>0
+      testor[3] <- length(dbasef$Gender[dbasef$Gender==2])>0
+
+      # loop over genders combinations
+      for(k in (1:3)[testor])
+      {
+        if(k==1){dbase_k <- dbasef[dbasef$Gender==1 & dbasef$Pick_gender==0,]}
+        if(k==2){dbase_k <- dbasef[dbasef$Gender==1 & dbasef$Pick_gender %in% c(1,3),]}
+        if(k==3){dbase_k <- dbasef[dbasef$Gender==2,]}
+        sex <- ifelse(k==3, 2, 1)
+
+        # loop over partitions (discard, retain, total)
+        for(j in unique(dbase_k$Part))
+        {
+          # dbase is the final data.frame used in the individual plots
+          # it is subset based on the kind (age, len, age-at-len), fleet, gender, and partition
+          dbase <- dbase_k[dbase_k$Part==j,]
+          if(nrow(dbase)>0){
+            ## assemble pieces of plot title
+            # sex
+            if(k==1) titlesex <- "sexes combined, "
+            if(k==2) titlesex <- "female, "
+            if(k==3) titlesex <- "male, "
+            titlesex <- ifelse(printsex,titlesex,"")
   
+            # market category
+            if(j==0) titlemkt <- "whole catch, "
+            if(j==1) titlemkt <- "discard, "
+            if(j==2) titlemkt <- "retained, "
+            titlemkt <- ifelse(printmkt,titlemkt,"")
+  
+            # plot bars for data only or if input 'fitbar=TRUE'
+            if(datonly | fitbar) bars <- TRUE else bars <- FALSE
+  
+            # aggregating identifiers for plot titles and filenames
+            title_sexmkt <- paste(titlesex,titlemkt,sep="")
+            filename_fltsexmkt <- paste("sex",k,"mkt",j,sep="")
+  
+            ptitle <- paste(titledata,title_sexmkt, "\naggregated within season by fleet",sep="") # total title
+            titles <- c(ptitle,titles) # compiling list of all plot titles
+  
+            Bins <- sort(unique(dbase$Bin))
+            nbins <- length(Bins)
+            df <- data.frame(N=dbase$N,
+                             effN=dbase$effN,
+                             obs=dbase$Obs*dbase$N,
+                             exp=dbase$Exp*dbase$N)
+            agg <- aggregate(x=df, by=list(bin=dbase$Bin,f=dbase$Fleet,s=dbase$Seas), FUN=sum)
+            agg <- agg[agg$f %in% fleets,]
+            agg$obs <- agg$obs/agg$N
+            agg$exp <- agg$exp/agg$N
+            # note: sample sizes will be different for each bin if tail compression is used
+            #       printed sample sizes in plot will be maximum, which may or may not
+            #       represent sum of sample sizes over all years/ages
+            for(f in unique(agg$f)){
+              for(s in unique(agg$s[agg$ff==f])){
+                infleetseas <- agg$f==f & agg$s==s
+                agg$N[infleetseas] <- max(agg$N[infleetseas])
+                agg$effN[infleetseas] <- max(agg$effN[infleetseas])
+              }
+            }
+            agg$fseas <- agg$f + seasfracs[agg$s]
+
+            namesvec <- paste(fleetnames[agg$f]," s",agg$s,sep="")
+
+            # group remaining calculations as a function
+            tempfun <- function(ipage,...){
+              if(!(kind %in% c("GSTAGE","GSTLEN","L@A","W@A"))){
+                make_multifig(ptsx=agg$bin,ptsy=agg$obs,yr=agg$fseas,
+                              linesx=agg$bin,linesy=agg$exp,
+                              sampsize=agg$N,effN=agg$effN,
+                              showsampsize=showsampsize,showeffN=showeffN,
+                              bars=bars,linepos=(1-datonly)*linepos,
+                              nlegends=3,
+                              legtext=list(namesvec,"sampsize","effN"),
+                              main=ptitle,cex.main=cex.main,xlab=kindlab,ylab=labels[6],
+                              maxrows=maxrows,maxcols=maxcols,rows=rows,cols=cols,
+                              fixdims=fixdims2,ipage=ipage,lwd=2,scalebins=scalebins,...)
+              }
+  
+         # haven't configured this aggregated plot for other types
+              ## if(kind=="GSTAGE"){
+              ##   make_multifig(ptsx=dbase$Bin,ptsy=dbase$Obs,yr=dbase$Yr,linesx=dbase$Bin,linesy=dbase$Exp,
+              ##                 sampsize=dbase$N,effN=dbase$effN,showsampsize=FALSE,showeffN=FALSE,
+              ##                 bars=bars,linepos=(1-datonly)*linepos,
+              ##                 nlegends=3,legtext=list(dbase$YrSeasName,"sampsize","effN"),
+              ##                 main=ptitle,cex.main=cex.main,xlab=kindlab,ylab=labels[6],
+              ##                 maxrows=maxrows,maxcols=maxcols,rows=rows,cols=cols,
+              ##                 fixdims=fixdims,ipage=ipage,...)
+              ## }
+              ## if(kind %in% c("L@A","W@A")){
+              ##   make_multifig(ptsx=dbase$Bin,ptsy=dbase$Obs,yr=dbase$Yr,linesx=dbase$Bin,linesy=dbase$Exp,
+              ##                 sampsize=dbase$N,effN=0,showsampsize=FALSE,showeffN=FALSE,
+              ##                 nlegends=1,legtext=list(dbase$YrSeasName),
+              ##                 bars=bars,linepos=(1-datonly)*linepos,
+              ##                 main=ptitle,cex.main=cex.main,xlab=kindlab,ylab=ifelse(kind=="W@A",labels[9],labels[1]),
+              ##                 maxrows=maxrows,maxcols=maxcols,rows=rows,cols=cols,
+              ##                 fixdims=fixdims,ipage=ipage,...)
+              ## }
+  
+            }
+            if(plot) tempfun(ipage=0,...) 
+            if(print){ # set up plotting to png file if required
+              npages <- ceiling(length(unique(agg$fseas))/maxrows/maxcols)
+              for(ipage in 1:npages)
+              {
+                if(npages>1) pagetext <- paste("_page",ipage,sep="") else pagetext <- ""
+                filename <- paste(plotdir,filenamestart,filename_fltsexmkt,pagetext,
+                                  "aggregated within season.png",sep="")
+                pngfun(file=filename)
+                tempfun(ipage=ipage,...)
+                dev.off()
+              }
+            } # end print function
+          } # end test for presence of observations in this partition
+        } # end loop over partitions
+      } # end loop over combined/not-combined genders
+    } # end if data
+  } # end subplot 10
+  
+  ### subplot 11: by fleet aggregating across years
+  if(11 %in% subplots & kind!="cond" & nseasons>1){ # for age or length comps, but not conditional AAL
+    # loop over fleets
+    for(f in fleets){
+      dbasef <- dbase_kind[dbase_kind$Fleet==f,]
+      # check for the presence of data
+      if(nrow(dbasef)>0){
+        testor    <- length(dbasef$Gender[dbasef$Gender==1 & dbasef$Pick_gender==0 ])>0
+        testor[2] <- length(dbasef$Gender[dbasef$Gender==1 & dbasef$Pick_gender %in% c(1,3)])>0
+        testor[3] <- length(dbasef$Gender[dbasef$Gender==2])>0
+        # loop over genders combinations
+        for(k in (1:3)[testor]){
+          if(k==1){dbase_k <- dbasef[dbasef$Gender==1 & dbasef$Pick_gender==0,]}
+          if(k==2){dbase_k <- dbasef[dbasef$Gender==1 & dbasef$Pick_gender %in% c(1,3),]}
+          if(k==3){dbase_k <- dbasef[dbasef$Gender==2,]}
+          sex <- ifelse(k==3, 2, 1)
+
+          # loop over partitions (discard, retain, total)
+          for(j in unique(dbase_k$Part)){
+            # dbase is the final data.frame used in the individual plots
+            # it is subset based on the kind (age, len, age-at-len), fleet, gender, and partition
+            dbase <- dbase_k[dbase_k$Part==j,]
+            if(nrow(dbase)>0){
+              ## assemble pieces of plot title
+              # sex
+              if(k==1) titlesex <- "sexes combined, "
+              if(k==2) titlesex <- "female, "
+              if(k==3) titlesex <- "male, "
+              titlesex <- ifelse(printsex,titlesex,"")
+              
+              # market category
+              if(j==0) titlemkt <- "whole catch, "
+              if(j==1) titlemkt <- "discard, "
+              if(j==2) titlemkt <- "retained, "
+              titlemkt <- ifelse(printmkt,titlemkt,"")
+              
+              # plot bars for data only or if input 'fitbar=TRUE'
+              if(datonly | fitbar) bars <- TRUE else bars <- FALSE
+              
+              # aggregating identifiers for plot titles and filenames
+              title_sexmkt <- paste(titlesex,titlemkt,sep="")
+              filename_fltsexmkt <- paste("flt",f,"sex",k,"mkt",j,sep="")
+
+              Bins <- sort(unique(dbase$Bin))
+              nbins <- length(Bins)
+              df <- data.frame(N=dbase$N,
+                               effN=dbase$effN,
+                               obs=dbase$Obs*dbase$N,
+                               exp=dbase$Exp*dbase$N)
+              agg <- aggregate(x=df, by=list(bin=dbase$Bin,f=dbase$Fleet,y=floor(dbase$Yr)), FUN=sum)
+              agg <- agg[agg$f %in% fleets,]
+              agg$obs <- agg$obs/agg$N
+              agg$exp <- agg$exp/agg$N
+              # note: sample sizes will be different for each bin if tail compression is used
+              #       printed sample sizes in plot will be maximum, which may or may not
+              #       represent sum of sample sizes over all years/ages
+              for(f in unique(agg$f)){
+                for(y in unique(agg$y[agg$ff==f])){
+                  infleetyr <- agg$f==f & agg$y==y
+                  agg$N[infleetyr] <- max(agg$N[infleetyr])
+                  agg$effN[infleetyr] <- max(agg$effN[infleetyr])
+                }
+              }
+              agg$fy <- agg$f + agg$y/10000
+
+              # group remaining calculations as a function
+              tempfun <- function(ipage,...){
+                ptitle <- paste(titledata,title_sexmkt,fleetnames[f], "\naggregated across seasons within year",sep="") # total title
+                titles <- c(ptitle,titles) # compiling list of all plot titles
+
+                if(!(kind %in% c("GSTAGE","GSTLEN","L@A","W@A"))){
+                  make_multifig(ptsx=agg$bin,ptsy=agg$obs,yr=agg$fy,
+                                linesx=agg$bin,linesy=agg$exp,
+                                sampsize=agg$N,effN=agg$effN,
+                                showsampsize=showsampsize,showeffN=showeffN,
+                                bars=bars,linepos=(1-datonly)*linepos,
+                                nlegends=3,
+                                legtext=list(agg$y,"sampsize","effN"),
+                                main=ptitle,cex.main=cex.main,xlab=kindlab,ylab=labels[6],
+                                maxrows=maxrows,maxcols=maxcols,rows=rows,cols=cols,
+                                fixdims=fixdims2,ipage=ipage,lwd=2,scalebins=scalebins,...)
+                }
+                
+                # haven't configured this aggregated plot for other types
+                ## if(kind=="GSTAGE"){
+                ##   make_multifig(ptsx=dbase$Bin,ptsy=dbase$Obs,yr=dbase$Yr,linesx=dbase$Bin,linesy=dbase$Exp,
+                ##                 sampsize=dbase$N,effN=dbase$effN,showsampsize=FALSE,showeffN=FALSE,
+                ##                 bars=bars,linepos=(1-datonly)*linepos,
+                ##                 nlegends=3,legtext=list(dbase$YrSeasName,"sampsize","effN"),
+                ##                 main=ptitle,cex.main=cex.main,xlab=kindlab,ylab=labels[6],
+                ##                 maxrows=maxrows,maxcols=maxcols,rows=rows,cols=cols,
+                ##                 fixdims=fixdims,ipage=ipage,...)
+                ## }
+                ## if(kind %in% c("L@A","W@A")){
+                ##   make_multifig(ptsx=dbase$Bin,ptsy=dbase$Obs,yr=dbase$Yr,linesx=dbase$Bin,linesy=dbase$Exp,
+                ##                 sampsize=dbase$N,effN=0,showsampsize=FALSE,showeffN=FALSE,
+                ##                 nlegends=1,legtext=list(dbase$YrSeasName),
+                ##                 bars=bars,linepos=(1-datonly)*linepos,
+                ##                 main=ptitle,cex.main=cex.main,xlab=kindlab,ylab=ifelse(kind=="W@A",labels[9],labels[1]),
+                ##                 maxrows=maxrows,maxcols=maxcols,rows=rows,cols=cols,
+                ##                 fixdims=fixdims,ipage=ipage,...)
+                ## }
+                
+              } # end tempfun
+
+              if(plot) tempfun(ipage=0,...) 
+              if(print){ # set up plotting to png file if required
+                npages <- ceiling(length(unique(agg$fy))/maxrows/maxcols)
+                for(ipage in 1:npages)
+                    {
+                      if(npages>1) pagetext <- paste("_page",ipage,sep="") else pagetext <- ""
+                      filename <- paste(plotdir,filenamestart,filename_fltsexmkt,pagetext,
+                                        "aggregated across seasons within year.png",sep="")
+                      pngfun(file=filename)
+                      tempfun(ipage=ipage,...)
+                      dev.off()
+                    }
+              } # end print function
+            } # end test for presence of observations in this partition
+          } # end loop over partitions
+        } # end loop over combined/not-combined genders
+      } # end if data
+    } # end loop over fleets
+  } # end subplot 11
+
   return(invisible(titles))
 } # end embedded SSplotComps function
 ###########################
